@@ -1,4 +1,5 @@
 [General]
 LogoPath=/home/me/kubuntu-circle-small.png
 Website=http://www.kubuntu.org
-
+Version=1.2.3
+Variant=Unstable Branches
