@@ -31,7 +31,8 @@
 #include <QRegExp>
 #include <QMenu>
 
-SidePanel::SidePanel(QWidget *parent) : QTreeView(parent)
+SidePanel::SidePanel(QWidget *parent)
+    : QTreeView(parent)
 {
     setHeaderHidden(true);
     setSortingEnabled(true);
@@ -46,13 +47,13 @@ SidePanel::SidePanel(QWidget *parent) : QTreeView(parent)
 
     setMouseTracking(true);
     setModel(m_proxyModel);
-    connect(this,SIGNAL(activated(QModelIndex)),this,SLOT(clickedSlot(QModelIndex)));
+    connect(this,&QAbstractItemView::activated,this,&SidePanel::clickedSlot);
     connect(this,SIGNAL(clicked(QModelIndex)),this,SLOT(clickedSlot(QModelIndex)));
 }
 
 SidePanel::~SidePanel()
 {
-    disconnect(this,SIGNAL(activated(QModelIndex)),this,SLOT(clickedSlot(QModelIndex)));
+    disconnect(this,&QAbstractItemView::activated,this,&SidePanel::clickedSlot);
     disconnect(this,SIGNAL(clicked(QModelIndex)),this,SLOT(clickedSlot(QModelIndex)));
 
     delete m_proxyModel;
@@ -140,5 +141,6 @@ QStringList SidePanel::allChildKeywords()
 void SidePanel::resetSearchSlot()
 {
     filterSideMenuSlot(QLatin1String(""));
+    Q_EMIT clearSearchLine();
 }
 
